# Hack4U Academy Couerses Library
 
Una bibilioteca Python para consultar cursos de la academia Hack4U

## Cursos disponibles:

- Introduccion a Linux [15 horas]
- Personalizacion de Linux [3 horas]
- Introduccion al Hacking [53 horas]

## Instalacion 

Instala el paquete usando  `pip3`:

```python3
pip3 install hack4u
```
